<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca">
<context>
    <name>AppearancePage</name>
    <message>
        <location filename="../appearancepage.ui" line="20"/>
        <source>Style:</source>
        <translation>Estil:</translation>
    </message>
    <message>
        <location filename="../appearancepage.ui" line="59"/>
        <source>Preview</source>
        <translation>Vista prèvia</translation>
    </message>
    <message>
        <location filename="../appearancepage.ui" line="69"/>
        <source>Active palette</source>
        <translation>Paleta activa</translation>
    </message>
    <message>
        <location filename="../appearancepage.ui" line="74"/>
        <source>Inactive palette</source>
        <translation>Paleta inactiva</translation>
    </message>
    <message>
        <location filename="../appearancepage.ui" line="79"/>
        <source>Disabled palette</source>
        <translation>Paleta desactivada</translation>
    </message>
    <message>
        <location filename="../appearancepage.ui" line="113"/>
        <source>Palette</source>
        <translation>Paleta</translation>
    </message>
    <message>
        <location filename="../appearancepage.ui" line="124"/>
        <location filename="../appearancepage.cpp" line="83"/>
        <source>Default</source>
        <translation>Predeterminada</translation>
    </message>
    <message>
        <location filename="../appearancepage.ui" line="134"/>
        <source>Custom</source>
        <translation>Personalitzada</translation>
    </message>
    <message>
        <location filename="../appearancepage.ui" line="161"/>
        <source>Color scheme:</source>
        <translation>Esquema de colors:</translation>
    </message>
    <message>
        <location filename="../appearancepage.ui" line="187"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../appearancepage.ui" line="218"/>
        <source>Standard dialogs:</source>
        <translation>Diàlegs estàndard:</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="70"/>
        <source>Create</source>
        <translation>Crea</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="71"/>
        <source>Edit</source>
        <translation>Edita</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="72"/>
        <source>Create a Copy</source>
        <translation>Crea una còpia</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="73"/>
        <source>Rename</source>
        <translation>Canvia el nom</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="75"/>
        <source>Remove</source>
        <translation>Suprimeix</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="137"/>
        <location filename="../appearancepage.cpp" line="211"/>
        <location filename="../appearancepage.cpp" line="250"/>
        <source>Enter Color Scheme Name</source>
        <translation>Introdueix el nom de l&apos;esquema de colors</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="137"/>
        <location filename="../appearancepage.cpp" line="211"/>
        <location filename="../appearancepage.cpp" line="250"/>
        <source>File name:</source>
        <translation>Nom del fitxer:</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="146"/>
        <location filename="../appearancepage.cpp" line="222"/>
        <location filename="../appearancepage.cpp" line="230"/>
        <location filename="../appearancepage.cpp" line="260"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="146"/>
        <location filename="../appearancepage.cpp" line="222"/>
        <location filename="../appearancepage.cpp" line="260"/>
        <source>The color scheme &quot;%1&quot; already exists</source>
        <translation>Ja existeix l&apos;esquema de colors «%1»</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="164"/>
        <location filename="../appearancepage.cpp" line="187"/>
        <location filename="../appearancepage.cpp" line="245"/>
        <source>Warning</source>
        <translation>Avís</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="164"/>
        <location filename="../appearancepage.cpp" line="187"/>
        <location filename="../appearancepage.cpp" line="245"/>
        <source>The color scheme &quot;%1&quot; is read only</source>
        <translation>L&apos;esquema de colors «%1» és de només lectura</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="192"/>
        <source>Confirm Remove</source>
        <translation>Confirma la supressió</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="193"/>
        <source>Are you sure you want to remove color scheme &quot;%1&quot;?</source>
        <translation>Segur que voleu suprimir l&apos;esquema de colors «%1»?</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="213"/>
        <source>%1 (copy)</source>
        <translation>%1 (còpia)</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="230"/>
        <source>Unable to copy file</source>
        <translation>No es pot copiar el fitxer</translation>
    </message>
</context>
<context>
    <name>FontConfigDialog</name>
    <message>
        <location filename="../fontconfigdialog.ui" line="14"/>
        <location filename="../fontconfigdialog.cpp" line="73"/>
        <source>Font Configuration</source>
        <translation>Configuració del tipus de lletra</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.ui" line="29"/>
        <source>Disable automatic hinting for bold fonts</source>
        <translation>Desactiva l&apos;optimització automàtica dels tipus de lletra en negreta</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.ui" line="36"/>
        <source>LCD filter:</source>
        <translation>Filtre LCD:</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.ui" line="43"/>
        <source>Automatic hinting</source>
        <translation>Optimizació automàtica</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.ui" line="50"/>
        <source>Hinting</source>
        <translation>Optimizació</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.ui" line="67"/>
        <source>Font resolution:</source>
        <translation>Resolució del tipus de lletra</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.ui" line="110"/>
        <source> dpi</source>
        <translation>ppp</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.ui" line="83"/>
        <source>Subpixel geometry:</source>
        <translation>Geometria dels subpíxels:</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.ui" line="90"/>
        <source>Antialiasing</source>
        <translation>Suavitzat</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.ui" line="97"/>
        <source>Hinting style:</source>
        <translation>Estil d&apos;optimizació</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.cpp" line="42"/>
        <location filename="../fontconfigdialog.cpp" line="47"/>
        <source>None</source>
        <translation>Desactiva</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.cpp" line="43"/>
        <source>Slight</source>
        <translation>Lleuger</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.cpp" line="44"/>
        <source>Medium</source>
        <translation>Mitjà</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.cpp" line="45"/>
        <source>Full</source>
        <translation>Complet</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.cpp" line="74"/>
        <source>&lt;i&gt;%1&lt;/i&gt; already exists. Do you want to replace it?</source>
        <translation>&lt;i&gt;%1&lt;/i&gt; ja existeix. Voleu reemplaçar-lo?</translation>
    </message>
</context>
<context>
    <name>FontsPage</name>
    <message>
        <location filename="../fontspage.ui" line="47"/>
        <location filename="../fontspage.ui" line="67"/>
        <location filename="../fontspage.ui" line="86"/>
        <location filename="../fontspage.ui" line="93"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../fontspage.ui" line="60"/>
        <source>General:</source>
        <translation>General:</translation>
    </message>
    <message>
        <location filename="../fontspage.ui" line="100"/>
        <source>Fixed width:</source>
        <translation>Amplada fixa:</translation>
    </message>
    <message>
        <location filename="../fontspage.ui" line="125"/>
        <source>Create  fonts.conf</source>
        <translation>Crea fonts.conf</translation>
    </message>
    <message>
        <location filename="../fontspage.ui" line="132"/>
        <source>Remove fonts.conf</source>
        <translation>Suprimeix fonts.conf</translation>
    </message>
    <message>
        <location filename="../fontspage.cpp" line="110"/>
        <source>Remove Font Configuration</source>
        <translation>Suprimeix la configuració dels tipus de lletra</translation>
    </message>
    <message>
        <location filename="../fontspage.cpp" line="111"/>
        <source>Are you sure you want to delete &lt;i&gt;%1&lt;/i&gt;?</source>
        <translation>Segur que voleu suprimir &lt;i&gt;%1&lt;/i&gt;?</translation>
    </message>
</context>
<context>
    <name>InterfacePage</name>
    <message>
        <location filename="../interfacepage.ui" line="35"/>
        <source>Double click interval:</source>
        <translation>Interval de doble clic</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="42"/>
        <source>Cursor flash time:</source>
        <translation>Temps de parpelleig del cursor:</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="49"/>
        <source>ComboBox effect:</source>
        <translation>Efecte del quadre combinat</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="56"/>
        <source>ToolTip effect:</source>
        <translation>Efecte de l&apos;indicador de funció</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="63"/>
        <source>ToolBox effect:</source>
        <translation>Efecte de la caixa d&apos;eines</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="70"/>
        <location filename="../interfacepage.ui" line="80"/>
        <source> ms</source>
        <translation>ms</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="94"/>
        <location filename="../interfacepage.ui" line="111"/>
        <location filename="../interfacepage.ui" line="133"/>
        <location filename="../interfacepage.ui" line="157"/>
        <source>Disable</source>
        <translation>Desactiva</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="99"/>
        <location filename="../interfacepage.ui" line="116"/>
        <location filename="../interfacepage.ui" line="138"/>
        <location filename="../interfacepage.ui" line="162"/>
        <source>Animate</source>
        <translation>Animació</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="121"/>
        <location filename="../interfacepage.ui" line="167"/>
        <source>Fade</source>
        <translation>Esvaïment</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="146"/>
        <source>Menu effect:</source>
        <translation>Efecte del menú</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="175"/>
        <source>Enable gui effects</source>
        <translation>Activa els efectes de la interfície</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="182"/>
        <source>Dialog buttons layout:</source>
        <translation>Disposició dels botons de diàleg:</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="192"/>
        <source>Keyboard scheme:</source>
        <translation>Disposició del teclat</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="202"/>
        <source>Menus have icons</source>
        <translation>Menús amb icones</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="209"/>
        <source>Dialog buttons have icons</source>
        <translation>Botons de diàleg amb icones</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="219"/>
        <source>Activate item on single-click</source>
        <translation>Activa els elements amb un sol clic</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="229"/>
        <source>Toolbar button style:</source>
        <translation>Estil dels botons de la barra d&apos;eines:</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="239"/>
        <source>Mouse wheel scroll lines:</source>
        <translation>Línies de desplaçament de la roda del ratolí</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="256"/>
        <source>Show shortcut underlines</source>
        <translation>Mostra el subratllat de les dreceres</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="266"/>
        <source>Show shortcuts in context menus</source>
        <translation>Mostra les dreceres als menús contextuals</translation>
    </message>
    <message>
        <location filename="../interfacepage.cpp" line="55"/>
        <source>Only display the icon</source>
        <translation>Mostra només la icona</translation>
    </message>
    <message>
        <location filename="../interfacepage.cpp" line="56"/>
        <source>Only display the text</source>
        <translation>Mostra només el text</translation>
    </message>
    <message>
        <location filename="../interfacepage.cpp" line="57"/>
        <source>The text appears beside the icon</source>
        <translation>Mostra el text al costat de la icona</translation>
    </message>
    <message>
        <location filename="../interfacepage.cpp" line="58"/>
        <source>The text appears under the icon</source>
        <translation>Mostra el text a sota de la icona</translation>
    </message>
    <message>
        <location filename="../interfacepage.cpp" line="59"/>
        <source>Follow the application style</source>
        <translation>Segueix l&apos;estil de l&apos;aplicació</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>Qt6 Configuration Tool</source>
        <translation>Eina de configuració de Qt6</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="54"/>
        <source>The application is not configured correctly.</source>
        <translation>No s&apos;ha configurat correctament l&apos;aplicació.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="61"/>
        <source>Information</source>
        <translation>Informació</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="68"/>
        <source>Hide</source>
        <translation>Amaga</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="51"/>
        <source>Appearance</source>
        <translation>Aparença</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="52"/>
        <source>Fonts</source>
        <translation>Tipus de lletra</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="53"/>
        <source>Icon Theme</source>
        <translation>Tema d&apos;icones</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="54"/>
        <source>Interface</source>
        <translation>Interfície</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="56"/>
        <source>Style Sheets</source>
        <translation>Fulls d&apos;estil</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="58"/>
        <source>Troubleshooting</source>
        <translation>Solució de problemes</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="65"/>
        <source>Version: %1</source>
        <translation>Versió: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="110"/>
        <source>Warning</source>
        <translation>Avís</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="119"/>
        <source>Please remove the &lt;b&gt;QT_STYLE_OVERRIDE&lt;/b&gt; environment variable (current value: &lt;b&gt;%1&lt;/b&gt;).</source>
        <translation>Suprimiu la variable d&apos;entorn &lt;b&gt;QT_STYLE_OVERRIDE&lt;/b&gt; (valor actual: &lt;b&gt;%1&lt;/b&gt;).</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="125"/>
        <source>The &lt;b&gt;QT_QPA_PLATFORMTHEME&lt;/b&gt; environment variable is not set (required values: &lt;b&gt;qt6ct&lt;/b&gt; or &lt;b&gt;qt5ct&lt;/b&gt;).</source>
        <translation>No s&apos;ha configurat la variable d&apos;entorn &lt;b&gt;QT_QPA_PLATFORMTHEME&lt;/b&gt; (valors obligatoris: &lt;b&gt;qt6ct&lt;/b&gt; o &lt;b&gt;qt5ct&lt;/b&gt;).</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="130"/>
        <source>The &lt;b&gt;QT_QPA_PLATFORMTHEME&lt;/b&gt; environment variable is not set correctly (current value: &lt;b&gt;%1&lt;/b&gt;, required values: &lt;b&gt;qt6ct&lt;/b&gt; or &lt;b&gt;qt5ct&lt;/b&gt;).</source>
        <translation>No s&apos;ha configurat correctament la variable d&apos;entorn &lt;b&gt;QT_QPA_PLATFORMTHEME&lt;/b&gt; (valor actual: &lt;b&gt;%1&lt;/b&gt;, valors obligatoris: &lt;b&gt;qt6ct&lt;/b&gt; o &lt;b&gt;qt5ct&lt;/b&gt;).</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="137"/>
        <source>Unable to find &lt;b&gt;libqt6ct-style.so&lt;/b&gt;</source>
        <translation>No es pot trobar &lt;b&gt;libqt6ct-style.so&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="143"/>
        <source>The &lt;b&gt;%1&lt;/b&gt; plugin is compiled against incompatible Qt version (%2).</source>
        <translation>El complement &lt;b&gt;%1&lt;/b&gt; s&apos;ha compilat amb una versió de Qt incompatible (%2).</translation>
    </message>
</context>
<context>
    <name>PaletteEditDialog</name>
    <message>
        <location filename="../paletteeditdialog.ui" line="14"/>
        <source>Palette Editor</source>
        <translation>Editor de la paleta</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.ui" line="79"/>
        <source>Reset palette</source>
        <translation>Restableix la paleta</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.ui" line="29"/>
        <source>Build inactive palette</source>
        <translation>Crea la paleta inactiva</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.ui" line="36"/>
        <source>Build disabled palette</source>
        <translation>Crea la paleta desactivada</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="48"/>
        <source>Active</source>
        <translation>Activa</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="48"/>
        <source>Inactive</source>
        <translation>Inactiva</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="48"/>
        <source>Disabled</source>
        <translation>Desactivada</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="90"/>
        <source>Dark</source>
        <translation>Fosc</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="90"/>
        <source>Window text</source>
        <translation>Text de la finestra</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="90"/>
        <source>Button background</source>
        <translation>Fons del botó</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="90"/>
        <source>Bright</source>
        <translation>Brillant</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="90"/>
        <source>Less bright</source>
        <translation>Menys brillant</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="90"/>
        <source>Less dark</source>
        <translation>Menys fosc</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="91"/>
        <source>Window</source>
        <translation>Finestra</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="91"/>
        <source>Shadow</source>
        <translation>Ombra</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="91"/>
        <source>Bright text</source>
        <translation>Text brillant</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="91"/>
        <source>Button text</source>
        <translation>Text del botó</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="91"/>
        <source>Normal text</source>
        <translation>Text normal</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="91"/>
        <source>Normal background</source>
        <translation>Fons normal</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="92"/>
        <source>Highlight</source>
        <translation>Ressaltat</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="92"/>
        <source>Highlighted text</source>
        <translation>Text ressaltat</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="92"/>
        <source>Visited link</source>
        <translation>Enllaç visitat</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="93"/>
        <source>Default</source>
        <translation>Per defecte</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="93"/>
        <source>Tooltip background</source>
        <translation>Fons de l&apos;indicador de funció</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="93"/>
        <source>Tooltip text</source>
        <translation>Text de l&apos;indicador de funció</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="92"/>
        <source>Link</source>
        <translation>Enllaç</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="92"/>
        <source>Alternate background</source>
        <translation>Fons alternatiu</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="93"/>
        <source>Placeholder text</source>
        <translation>Text de farciment</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="107"/>
        <source>Select Color</source>
        <translation>Selecciona el color</translation>
    </message>
</context>
<context>
    <name>PreviewForm</name>
    <message>
        <location filename="../previewform.ui" line="14"/>
        <source>Preview Window</source>
        <translation>Finestra de vista prèvia</translation>
    </message>
    <message>
        <location filename="../previewform.ui" line="27"/>
        <source>Tab 1</source>
        <translation>Pestanya 1</translation>
    </message>
    <message>
        <location filename="../previewform.ui" line="36"/>
        <source>PushButton</source>
        <translation>Botó</translation>
    </message>
    <message>
        <location filename="../previewform.ui" line="65"/>
        <source>Tab 2</source>
        <translation>Pestanya 2</translation>
    </message>
    <message>
        <location filename="../previewform.ui" line="74"/>
        <source>RadioButton</source>
        <translation>Botó d&apos;opció</translation>
    </message>
    <message>
        <location filename="../previewform.ui" line="84"/>
        <source>CheckBox</source>
        <translation>Casella de selecció</translation>
    </message>
</context>
<context>
    <name>QSSEditorDialog</name>
    <message>
        <location filename="../qsseditordialog.cpp" line="46"/>
        <source>%1 - Style Sheet Editor</source>
        <translation>%1 - Editor de fulls d&apos;estil</translation>
    </message>
    <message>
        <location filename="../qsseditordialog.ui" line="14"/>
        <source>Style Sheet Editor</source>
        <translation>Editor de fulls d&apos;estil</translation>
    </message>
</context>
<context>
    <name>QSSPage</name>
    <message>
        <location filename="../qsspage.ui" line="23"/>
        <source>Create</source>
        <translation>Crea</translation>
    </message>
    <message>
        <location filename="../qsspage.ui" line="66"/>
        <location filename="../qsspage.cpp" line="51"/>
        <location filename="../qsspage.cpp" line="87"/>
        <source>Edit</source>
        <translation>Edita</translation>
    </message>
    <message>
        <location filename="../qsspage.ui" line="76"/>
        <location filename="../qsspage.cpp" line="53"/>
        <source>Rename</source>
        <translation>Canvia el nom</translation>
    </message>
    <message>
        <location filename="../qsspage.ui" line="33"/>
        <location filename="../qsspage.cpp" line="55"/>
        <source>Remove</source>
        <translation>Elimina</translation>
    </message>
    <message>
        <location filename="../qsspage.cpp" line="52"/>
        <source>Create a Copy</source>
        <translation>Crea una còpia</translation>
    </message>
    <message>
        <location filename="../qsspage.cpp" line="92"/>
        <source>View</source>
        <translation>Vista</translation>
    </message>
    <message>
        <location filename="../qsspage.cpp" line="106"/>
        <location filename="../qsspage.cpp" line="251"/>
        <source>File name:</source>
        <translation>Nom del fitxer:</translation>
    </message>
    <message>
        <location filename="../qsspage.cpp" line="106"/>
        <location filename="../qsspage.cpp" line="251"/>
        <source>Enter Style Sheet Name</source>
        <translation>Escriu el nom del full d&apos;estil</translation>
    </message>
    <message>
        <location filename="../qsspage.cpp" line="117"/>
        <location filename="../qsspage.cpp" line="218"/>
        <location filename="../qsspage.cpp" line="226"/>
        <location filename="../qsspage.cpp" line="263"/>
        <location filename="../qsspage.cpp" line="271"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../qsspage.cpp" line="117"/>
        <source>The file &quot;%1&quot; already exists</source>
        <translation>Ja existeix el fitxer «%1»</translation>
    </message>
    <message>
        <location filename="../qsspage.cpp" line="151"/>
        <source>Confirm Remove</source>
        <translation>Confirma la supressió</translation>
    </message>
    <message>
        <location filename="../qsspage.cpp" line="152"/>
        <source>Are you sure you want to remove style sheet &quot;%1&quot;?</source>
        <translation>Segur que voleu suprimir el full d&apos;estil «%1»?</translation>
    </message>
    <message>
        <location filename="../qsspage.cpp" line="208"/>
        <source>Rename Style Sheet</source>
        <translation>Canvia el nom del full d&apos;estil</translation>
    </message>
    <message>
        <location filename="../qsspage.cpp" line="208"/>
        <source>Style sheet name:</source>
        <translation>Nom del full d&apos;estil:</translation>
    </message>
    <message>
        <location filename="../qsspage.cpp" line="218"/>
        <location filename="../qsspage.cpp" line="263"/>
        <source>The style sheet &quot;%1&quot; already exists</source>
        <translation>Ja existeix el full d&apos;estil «%1»</translation>
    </message>
    <message>
        <location filename="../qsspage.cpp" line="226"/>
        <source>Unable to rename file</source>
        <translation>No es pot canviar el nom del fitxer</translation>
    </message>
    <message>
        <location filename="../qsspage.cpp" line="253"/>
        <source>%1 (copy).qss</source>
        <translation>%1 (còpia).qss</translation>
    </message>
    <message>
        <location filename="../qsspage.cpp" line="271"/>
        <source>Unable to copy file</source>
        <translation>No es pot copiar el fitxer</translation>
    </message>
</context>
<context>
    <name>TroubleshootingPage</name>
    <message>
        <location filename="../troubleshootingpage.ui" line="20"/>
        <source>Ignored applications:</source>
        <translation>Aplicacions ignorades: </translation>
    </message>
    <message>
        <location filename="../troubleshootingpage.ui" line="29"/>
        <source>Add...</source>
        <translation>Afegeix...</translation>
    </message>
    <message>
        <location filename="../troubleshootingpage.ui" line="40"/>
        <source>Remove</source>
        <translation>Suprimeix</translation>
    </message>
    <message>
        <location filename="../troubleshootingpage.ui" line="73"/>
        <source>Do not apply any styles and color schemes for the listed applications.</source>
        <translation>No apliquis estils ni esquemes de colors per a les aplicacions enumerades. </translation>
    </message>
    <message>
        <location filename="../troubleshootingpage.ui" line="82"/>
        <source>Make top-level widgets use pure raster surfaces, and do not support non-native GL-based child widgets.</source>
        <translation>Fes que els components de nivell superior usin superfícies facin servir rasteritzades pures i no admetin components secundaris no nadius basats en GL. </translation>
    </message>
    <message>
        <location filename="../troubleshootingpage.ui" line="85"/>
        <source>Force raster surface</source>
        <translation>Força la superfície rasteritzada </translation>
    </message>
    <message>
        <location filename="../troubleshootingpage.cpp" line="64"/>
        <source>Select Application</source>
        <translation>Selecciona l&apos;aplicació</translation>
    </message>
    <message>
        <location filename="../troubleshootingpage.cpp" line="64"/>
        <source>Executable files (*)</source>
        <translation>Ftixers executables (*)</translation>
    </message>
</context>
</TS>
